# Synonyms Package

This Python package provides a JSON file containing synonyms for the Hindi language. You can access the synonyms via the package.

## Installation

```bash
pip install synonyms-package
